@@ -29,6 +29,7 @@ $('<script>')
         src: local_uri_prefix + 'js/spectrum.js'
     });
 
+
 exports.last_timestamp = 0;
 
 // Set panels to close on escape system-wide
@@ -489,7 +490,7 @@ exports.GetDeviceFields = function(selected) {
             rawret.push(cols[i]['field']);
 
         if ('fields' in cols[i] && cols[i]['fields'] != null) 
-            cols[i]['fields'].forEach(function(e) { rawret.push.apply(rawret, e); });
+            rawret.push.apply(rawret, cols[i]['fields']);
     }
 
     for (var i in DeviceRowHighlights) {
@@ -527,7 +528,7 @@ exports.AddDetail = function(container, id, title, pos, options) {
 
 exports.DetailWindow = function(key, title, options, window_cb, close_cb) {
     // Generate a unique ID for this dialog
-    var dialogid = "detailialog" + key;
+    var dialogid = "detaildialog" + key;
     var dialogmatch = '#' + dialogid;
 
     if (jsPanel.activePanels.list.indexOf(dialogid) != -1) {
@@ -743,6 +744,8 @@ exports.DeviceDetailWindow = function(key) {
             };
 
             panel.updater();
+
+            new ClipboardJS('.copyuri');
         },
 
         function(panel, options) {
@@ -812,7 +815,7 @@ exports.GetPhyConvertedChannel = function(phyname, frequency) {
     return kismet.HumanReadableFrequency(frequency);
 }
 
-exports.connection_error = false;
+exports.connection_error = 0;
 exports.connection_error_panel = null;
 
 exports.HealthCheck = function() {
@@ -823,16 +826,21 @@ exports.HealthCheck = function() {
             .done(function(data) {
                 data = kismet.sanitizeObject(data);
 
-                if (exports.connection_error) {
-                    exports.connection_error_panel.close();
+                if (exports.connection_error && exports.connection_error_panel) {
+                    try {
+                        exports.connection_error_panel.close();
+                        exports.connection_error_panel = null;
+                    } catch (e) {
+                        ;
+                    }
                 }
 
-                exports.connection_error = false;
+                exports.connection_error = 0;
 
                 exports.last_timestamp = data['kismet.system.timestamp.sec'];
             })
             .fail(function() {
-                if (!exports.connection_error) {
+                if (exports.connection_error >= 3 && exports.connection_error_panel == null) {
                     exports.connection_error_panel = $.jsPanel({
                         id: "connection-alert",
                         headerTitle: 'Cannot Connect to Kismet',
@@ -846,7 +854,7 @@ exports.HealthCheck = function() {
                     });
                 }
 
-                exports.connection_error = true;
+                exports.connection_error++;
             })
             .always(function() {
                 if (exports.connection_error)
@@ -1148,18 +1156,22 @@ exports.InitializeDeviceTable = function(element) {
 
     $('tbody', element)
         .on( 'mouseenter', 'td', function () {
-            var device_dt = element.DataTable();
+            try {
+                var device_dt = element.DataTable();
 
-            if (typeof(device_dt.cell(this).index()) === 'Undefined')
-                return;
+                if (typeof(device_dt.cell(this).index()) === 'Undefined')
+                    return;
 
-            var colIdx = device_dt.cell(this).index().column;
-            var rowIdx = device_dt.cell(this).index().row;
+                var colIdx = device_dt.cell(this).index().column;
+                var rowIdx = device_dt.cell(this).index().row;
 
-            // Remove from all cells
-            $(device_dt.cells().nodes()).removeClass('kismet-highlight');
-            // Highlight the td in this row
-            $('td', device_dt.row(rowIdx).nodes()).addClass('kismet-highlight');
+                // Remove from all cells
+                $(device_dt.cells().nodes()).removeClass('kismet-highlight');
+                // Highlight the td in this row
+                $('td', device_dt.row(rowIdx).nodes()).addClass('kismet-highlight');
+            } catch (e) {
+
+            }
         } );
 
 
